==> haskell-generic-data-1.1.0.2-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 generic-data
version:              1.1.0.2
visibility:           public
id:                   generic-data-1.1.0.2-I5GyErnzeUMF9n1ZDizRnL
key:                  generic-data-1.1.0.2-I5GyErnzeUMF9n1ZDizRnL
license:              MIT
copyright:            2018-2020 Li-yao Xia
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
homepage:             https://github.com/Lysxia/generic-data#readme
synopsis:             Deriving instances with GHC.Generics and related utilities
description:
    Generic implementations of standard type classes.
    Operations on generic representations to help using "GHC.Generics".
    See README.

category:             Generics
abi:                  4d75920c42ee93a93424ce4745430fd8
exposed:              True
exposed-modules:
    Generic.Data Generic.Data.Internal.Compat
    Generic.Data.Internal.Data Generic.Data.Internal.Enum
    Generic.Data.Internal.Error Generic.Data.Internal.Functions
    Generic.Data.Internal.Generically Generic.Data.Internal.Meta
    Generic.Data.Internal.Microsurgery Generic.Data.Internal.Newtype
    Generic.Data.Internal.Prelude Generic.Data.Internal.Read
    Generic.Data.Internal.Resolvers Generic.Data.Internal.Show
    Generic.Data.Internal.Traversable Generic.Data.Internal.Utils
    Generic.Data.Microsurgery Generic.Data.Orphans Generic.Data.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/generic-data-1.1.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/generic-data-1.1.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/generic-data-1.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-generic-data
hs-libraries:         HSgeneric-data-1.1.0.2-I5GyErnzeUMF9n1ZDizRnL
depends:
    ap-normalize-0.1.0.1-2OIZezFTFdID4zyW3I24kv base-4.17.2.1
    base-orphans-0.9.2-2yEP0IT4Qja76O8OBpj1Xy
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi ghc-boot-th-9.4.8
    show-combinators-0.2.0.0-6ZAszFLrSaHXY65bXLH1d

haddock-interfaces:
    /usr/share/doc/haskell-generic-data/html/generic-data.haddock

haddock-html:         /usr/share/doc/haskell-generic-data/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-generic-data-1.1.0.2-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 generic-data
version:              1.1.0.2
visibility:           public
id:                   generic-data-1.1.0.2-3r8uK0PJGBs7bNiuBwVRyu
key:                  generic-data-1.1.0.2-3r8uK0PJGBs7bNiuBwVRyu
license:              MIT
copyright:            2018-2020 Li-yao Xia
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
homepage:             https://github.com/Lysxia/generic-data#readme
synopsis:             Deriving instances with GHC.Generics and related utilities
description:
    Generic implementations of standard type classes.
    Operations on generic representations to help using "GHC.Generics".
    See README.

category:             Generics
abi:                  1d8c5dcbd9f38819a7910d6dbc8a671f
exposed:              True
exposed-modules:
    Generic.Data Generic.Data.Internal.Compat
    Generic.Data.Internal.Data Generic.Data.Internal.Enum
    Generic.Data.Internal.Error Generic.Data.Internal.Functions
    Generic.Data.Internal.Generically Generic.Data.Internal.Meta
    Generic.Data.Internal.Microsurgery Generic.Data.Internal.Newtype
    Generic.Data.Internal.Prelude Generic.Data.Internal.Read
    Generic.Data.Internal.Resolvers Generic.Data.Internal.Show
    Generic.Data.Internal.Traversable Generic.Data.Internal.Utils
    Generic.Data.Microsurgery Generic.Data.Orphans Generic.Data.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/generic-data-1.1.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/generic-data-1.1.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/generic-data-1.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-generic-data
hs-libraries:         HSgeneric-data-1.1.0.2-3r8uK0PJGBs7bNiuBwVRyu
depends:
    ap-normalize-0.1.0.1-2OIZezFTFdID4zyW3I24kv base-4.17.2.1
    base-orphans-0.9.2-LQGxCYkAh7aFvJ0uEheUzK
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi ghc-boot-th-9.4.8
    show-combinators-0.2.0.0-6ZAszFLrSaHXY65bXLH1d

haddock-interfaces:
    /usr/share/doc/haskell-generic-data/html/generic-data.haddock

haddock-html:         /usr/share/doc/haskell-generic-data/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
